use crate::vm::mem::DmAllocObject;
use std::rc::Rc;

#[derive(Debug, Clone, PartialEq)]
pub enum DvmValue {
    Byte(u8),
    Int(i32),
    Long(i64),
    Double(f64),
    Boolean(bool),
    Pointer(Rc<DmAllocObject>),
    Uninit,
    Void,
}

impl DvmValue {
    pub fn expect_long(&self) -> i64 {
        if let DvmValue::Long(l) = self {
            *l
        } else {
            panic!("Expected DvmValue::long, but found {:?}", self)
        }
    }

    pub fn expect_pointer(&self) -> Rc<DmAllocObject> {
        if let DvmValue::Pointer(p) = self {
            p.clone()
        } else {
            panic!("Expected DvmValue::Pointer, but found {:?}", self);
        }
    }
}
